<?php
/** Lozi (Silozi)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Litingatinga Silozi
 * @author Ooswesthoesbes
 * @author SF-Language
 */

$messages = array(
# User preference toggles
'tog-underline'            => "Tumana ling'ko:",
'tog-highlightbroken'      => 'Kamukile ling\'ki bufosi <a href="" class="new">sa</a> (lyam: sa<a href="" class="internal">?</a>).',
'tog-justify'              => 'Singanyekile silamina',
'tog-usenewrc'             => 'Inenset petuho nca (JavaScript)',
'tog-numberheadings'       => 'Auto-palo mukunguna',
'tog-showtoolbar'          => "Kamukile hloli ye ng'i toolbar (bulukezi JavaScript)",
'tog-editondblclick'       => "Hloli ye ng'i petulo di 'klik' dubo (JavaScript)",
'tog-editsection'          => "Nyembulisize [hloli ye ng'i] di akes di lyangutukezi ling'ki",
'tog-rememberpassword'     => 'Askevusize zwa menuhile kwa bye kompyuta (for a maximum of $1 {{PLURAL:$1|day|days}})',
'tog-watchcreations'       => 'Pusize petulo a hloli di zwa mukoloko di kentezi',
'tog-watchdefault'         => "Pusize petulo a hloli ye ng'i di zwa mukoloko di kentezi",
'tog-watchmoves'           => 'Pusize petulo a nyanganyisoze di zwa mukoloko di kentezi',
'tog-watchdeletion'        => 'Pusize petulo a afi kulobala di zwa mukoloko di kentezi',
'tog-previewontop'         => "Kamukile PendiBe pre boks di hloli ye ng'i",
'tog-previewonfirst'       => 'Kamukile PendiBe kwa afi 1',
'tog-nocache'              => 'Amutembwe petulo kahili',
'tog-enotifwatchlistpages' => 'Meli di zwa di petulo a kentezi sa petuhisize',
'tog-enotifusertalkpages'  => 'Meli di zwa di zwa bulelezi sa petuhisize',
'tog-enotifrevealaddr'     => 'Kamukile zwa adress di meli di xete peson kwa melina notifikasyona',
'tog-shownumberswatching'  => 'Kamukile tali di kentezi sebelu',
'tog-fancysig'             => "Ro sebu e data (dicon ling'ki auto)",
'tog-externaleditor'       => "Sebelize hloli ye ng'i ektenali dauto",
'tog-externaldiff'         => 'Sebelize petuho ektenali dauto',
'tog-showjumplinks'        => 'Nyembulisize "sinkumukezi" ling\'ki',
'tog-uselivepreview'       => 'Sebelize live PendiBe (bulukezi JavaScript) (yem nca)',
'tog-watchlisthideown'     => 'Cwankekile zwa afina di zwa mukoloko di kentezi',
'tog-watchlisthidebots'    => 'Cwankekile roboti di zwa mukoloko di kentezi',
'tog-nolangconversion'     => 'Dinyembulisize selti konfesyoni',
'tog-ccmeonemails'         => 'Afi di zwa dubina di melina a afi di xetewi sebelu',
'tog-diffonly'             => 'Ni sa kamukile petulo selt pre petuho',

'underline-always'  => 'Xet',
'underline-never'   => 'Yexet',
'underline-default' => 'Pokuhe',

# Dates
'sunday'        => 'La Pumulo',
'monday'        => 'La Mubulo',
'tuesday'       => 'La Bubeli',
'wednesday'     => 'La Bulalu',
'thursday'      => 'La Bune',
'friday'        => 'La Butanu',
'saturday'      => 'La Mukibelo',
'sun'           => 'Pum',
'mon'           => 'Mub',
'tue'           => 'Bub',
'wed'           => 'Bul',
'thu'           => 'Bun',
'fri'           => 'But',
'sat'           => 'Muk',
'january'       => 'Sopa',
'february'      => 'Yowa',
'march'         => 'Liatamanyi',
'april'         => 'Lungu',
'may_long'      => 'Kandao',
'june'          => 'Mbuwana',
'july'          => 'Sikulu',
'august'        => 'Muyana',
'september'     => 'Muimunene',
'october'       => 'Yenda',
'november'      => 'Njimwana',
'december'      => "Ng'ulule",
'january-gen'   => 'Sopa',
'february-gen'  => 'Yowa',
'march-gen'     => 'Liatamanyi',
'april-gen'     => 'Lungu',
'may-gen'       => 'Kandao',
'june-gen'      => 'Mbuwana',
'july-gen'      => 'Sikulu',
'august-gen'    => 'Muyana',
'september-gen' => 'Muimunene',
'october-gen'   => 'Yenda',
'november-gen'  => 'Njimwana',
'december-gen'  => "Ng'ulule",
'jan'           => 'Sop',
'feb'           => 'Yow',
'mar'           => 'Lia',
'apr'           => 'Lun',
'may'           => 'Kan',
'jun'           => 'Mbu',
'jul'           => 'Sik',
'aug'           => 'Muy',
'sep'           => 'Mui',
'oct'           => 'Yen',
'nov'           => 'Nji',
'dec'           => 'Ngu',

# Categories related messages
'pagecategories'         => '{{PLURAL:$1|Kattegori|Kattegorina}}',
'category_header'        => 'Kattegori petulo di "$1"',
'subcategories'          => 'Subkattegori',
'category-media-header'  => 'Kattegori media di "$1"',
'category-empty'         => "''Wo kattegori cwale fumile ishi petulo nji media.''",
'listingcontinuesabbrev' => 'kepoli',

'about'         => "Ngesi ye ng'i atulile",
'article'       => 'Petulo',
'newwindow'     => '(apuzi kwa nca windo)',
'cancel'        => 'Ngambu',
'moredotdotdot' => 'Ye plus...',
'mypage'        => 'Zwa petulo',
'mytalk'        => 'Zwa bulelezi',
'anontalk'      => 'Bulelezi di bye IP',
'navigation'    => 'Muya',
'and'           => '&#32;e',

# Cologne Blue skin
'qbfind'         => 'Fatukile',
'qbbrowse'       => 'Nepile',
'qbedit'         => "Hloli ye ng'i",
'qbpageoptions'  => 'Bye petulo',
'qbpageinfo'     => 'Petulo tuto',
'qbmyoptions'    => 'Zwa petulona',
'qbspecialpages' => 'Petulo zwenti',
'faq'            => 'Alabile',
'faqpage'        => 'Project:Alabile',

'errorpagetitle'    => 'Bufosi',
'returnto'          => 'Kutezi $1.',
'tagline'           => 'Di {{SITENAME}}',
'help'              => 'Likitisize',
'search'            => 'Fatukile',
'searchbutton'      => 'Fatukile',
'go'                => 'Afi',
'searcharticle'     => 'Afi',
'history'           => 'Bundau petulo',
'history_short'     => 'Bundau',
'updatedmarker'     => 'sa updeti di zwa sadi ladu',
'printableversion'  => "Petulo printezi ye ng'i",
'permalink'         => 'Permalink',
'print'             => 'Aprintile',
'edit'              => "Hloli ye ng'i",
'editthispage'      => "Hloli ye ng'i bye petulo",
'delete'            => 'Afi kulobala',
'deletethispage'    => 'Afi kulobala bye petulo',
'undelete_short'    => 'Afi kulobala tamuhile {{PLURAL:$1|1 hlolu|$1 hloluna}}',
'protect'           => 'Bukelezi',
'protect_change'    => 'fetuhile bukelezi',
'protectthispage'   => 'Bukelezi bye petulo',
'unprotect'         => 'bukelezi tamuhile',
'unprotectthispage' => 'Bukelezi tamuhile bye petulo',
'newpage'           => 'Petulo hlolinu',
'talkpage'          => 'Bulelezi bye petulo',
'talkpagelinktext'  => 'Bulelezi',
'specialpage'       => 'Petulo Zwenti',
'personaltools'     => 'Solume sisebelisoni',
'postcomment'       => 'Bulelezi mulumiwa',
'articlepage'       => 'Kamukile petulo',
'talk'              => 'Bulelezi',
'views'             => 'Kamukile',
'toolbox'           => 'Sisebelisoni',
'userpage'          => 'Kamukile sebelu petulo',
'projectpage'       => 'Kamukile prohyeti petulo',
'imagepage'         => 'Kamukile imegi petulo',
'mediawikipage'     => 'Kamukile mulumiwa',
'templatepage'      => 'Kamukile yegani petulo',
'viewhelppage'      => 'Kamukile likitisize petulo',
'categorypage'      => 'Kamukile kattegori',
'viewtalkpage'      => 'Kamukile bulelezi',
'otherlanguages'    => 'Silozi kibuzi',
'redirectedfrom'    => '(Petulo abezi di $1)',
'redirectpagesub'   => 'Petulo abezi',
'lastmodifiedat'    => 'Bye petulo sa petuhisize di lila kwa $2, $1.',
'viewcount'         => 'Bye petulo sa akusi {{PLURAL:$1|1×|$1×}}.',
'protectedpage'     => 'Petulo bukelezi',
'jumpto'            => 'Yezi:',
'jumptonavigation'  => 'muya',
'jumptosearch'      => 'fatukile',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => "Ngesi ye ng'i atulile {{SITENAME}}",
'aboutpage'            => "Project:Ngesi ye ng'i atulile",
'copyright'            => 'Bye sa ilonungi di $1.',
'copyrightpage'        => "{{ns:project}}:Copyright ng'i",
'currentevents'        => 'Muembatami',
'currentevents-url'    => 'Project:Muembatami',
'disclaimers'          => 'Dikulemi',
'disclaimerpage'       => 'Project:Dikulemi generali',
'edithelp'             => "Hloli ye ng'i",
'edithelppage'         => "Help:Hloli ye ng'i",
'helppage'             => 'Help:Buinaneli di petulo',
'mainpage'             => 'Petulo yem efro',
'mainpage-description' => 'Petulo yem efro',
'policy-url'           => 'Project:Busize',
'portal'               => 'Petulo Bulili',
'portal-url'           => 'Project:Petulo Bulili',
'privacy'              => 'Busize likunutu',
'privacypage'          => 'Project:Busize likunutu',

'badaccess'        => 'Bufosi pemiko',
'badaccess-group0' => 'Zwa eksyon ni sa di sebelu kwa zwa kattegorina. Kyon ni sa vanu.',
'badaccess-groups' => 'Zwa eksyon sa di sebelu kwa 1 di kattegorina $1.',

'versionrequired'     => 'Pane $1 di MediaWiki sa nidyisize',
'versionrequiredtext' => 'Pane $1 di MediaWiki sa nidyisize di sebesize bye petulo. Kamukile [[Special:Version|pane]].',

'ok'                      => 'lumelisize',
'retrievedfrom'           => 'Bulukezi ye ng\'i di "$1"',
'youhavenewmessages'      => 'A sa pozefisize $1 ($2).',
'newmessageslink'         => 'nca mulumiwani',
'newmessagesdifflink'     => 'nca petuho te-i',
'youhavenewmessagesmulti' => 'Nca $1 mulumiwani',
'editsection'             => "hloli ye ng'i",
'editold'                 => "hloli ye ng'i",
'editsectionhint'         => "Hloli ye ng'i silami: $1",
'toc'                     => 'Petuloni',
'showtoc'                 => 'kamukile',
'hidetoc'                 => 'cwankekile',
'thisisdeleted'           => 'Kamukile/afi kulobala tamuhile $1?',
'viewdeleted'             => 'Kamukile $1?',
'restorelink'             => '{{PLURAL:$1|1 afi bye sa afi kulobala|$1 afina bye sa afi kulobala}}',
'feedlinks'               => 'Feed (sa sadumi kabili padi):',
'feed-invalid'            => 'Subskripsyon feed tapi bufosi.',
'site-rss-feed'           => '$1 RSS Feed (sa sadumi kabili padi)',
'site-atom-feed'          => '$1 Atom Feed (sa sadumi kabili padi)',
'page-rss-feed'           => '"$1" RSS Feed (sa sadumi kabili padi)',
'page-atom-feed'          => '"$1" Atom Feed (sa sadumi kabili padi)',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Petulo',
'nstab-user'      => 'Sebelu petulo',
'nstab-media'     => 'Media',
'nstab-special'   => 'Zwenti',
'nstab-project'   => 'Prohyeti petulo',
'nstab-image'     => 'Imegi',
'nstab-mediawiki' => 'Mulumiwa',
'nstab-template'  => 'Yegani',
'nstab-help'      => 'Likitisize',
'nstab-category'  => 'Kattegori',

# Main script and global functions
'nosuchaction'      => 'Ni eksyon',
'nosuchspecialpage' => 'Ni petulo zwenti',

# General errors
'error'                => 'Bufosi',
'databaseerror'        => 'Bufosi di database',
'readonly'             => 'Databesi sa loko',
'internalerror'        => 'Interni bufosi',
'internalerror_info'   => 'Interni bufosi: $1',
'filecopyerror'        => 'Ni sa dubolisize media "$1" di "$2".',
'filerenameerror'      => 'Ni sa nyanganyisize media "$1" di "$2".',
'filedeleteerror'      => 'Ni sa afi kulobala media "$1".',
'directorycreateerror' => 'Ni sa hloli direktori "$1".',
'filenotfound'         => 'Ni sa fatukile media "$1".',
'fileexistserror'      => 'Ni sa ubelisize di media "$1": media sa',
'unexpected'           => 'Teko lishokomoki: "$1"="$2".',
'formerror'            => 'Bufosi: ni bulukezi form',
'badtitle'             => 'Sebu sa bani',
'badtitletext'         => "Bufosi di petulo sigirikisize, kusize, interling'ki. A sa selt di bufosi.",
'wrong_wfQuery_params' => "Inkorrekt parameteri di wfQuery()<br />
Fung'ksyun: $1<br />
Query: $2",
'viewsource'           => "Kamukile ng'i",
'viewsourcefor'        => 'di $1',
'viewsourcetext'       => 'A sa kamukile wiki-selt di bye petulo:',
'sqlhidden'            => '(SQL query sa cwankekile)',

# Login and logout pages
'yourname'                => 'Sebelu:',
'yourpassword'            => 'Sebu dafi:',
'yourpasswordagain'       => 'Ritapi sebu dafi:',
'remembermypassword'      => 'Askevusize zwa menuhile kwa bye kompyuta (for a maximum of $1 {{PLURAL:$1|day|days}})',
'yourdomainname'          => 'Zwa domeni:',
'login'                   => 'Menuhile',
'nav-login-createaccount' => 'Menuhile / ipupezi sebelu',
'loginprompt'             => 'A sa nyembulisize di kukina di menuhile kwa {{SITENAME}}.',
'userlogin'               => 'Menuhile / ipupezi sebelu',
'logout'                  => 'Ile',
'userlogout'              => 'Ile',
'notloggedin'             => 'Ile sa akwezi',
'nologin'                 => "Ni menuhile? '''$1'''.",
'nologinlink'             => 'Ipupezi sebelu',
'createaccount'           => 'Ipupezi sebelu',
'gotaccount'              => "Xete a sa sebelu? '''$1'''.",
'gotaccountlink'          => 'Menuhile',
'createaccountmail'       => 'dimeli',
'badretype'               => 'Sebu dafi ni sa identikali.',
'userexists'              => 'Sebu di sebelu sa sebelize. Hloli veti sebu petuho.',
'loginerror'              => 'Bufosi di menuhile',
'nocookieslogin'          => '{{SITENAME}} sebelize kukina di menuhile sebelu. A ni sa kukina. Sa kukina.',
'noname'                  => 'A sa sebelu consa sebelu bufosi.',
'loginsuccesstitle'       => 'Menuhile ni condi bufosi',
'loginsuccess'            => "'''A sa menuhile di {{SITENAME}} con sebelu \"\$1\".'''",
'nosuchuser'              => 'No sebelu "$1". Tembile/ipupezi.',
'nosuchusershort'         => 'No sebelu "$1". Tembile.',
'nouserspecified'         => 'A tumbelezi sebelunom.',
'wrongpassword'           => 'Bufosi sebu dafi. Tembile.',
'wrongpasswordempty'      => 'No sebu dafi. Tembile.',
'passwordtooshort'        => 'Zwa sebu dafi sa bufosi/kuswani. A sa $1 di selt e petuho di zwa sebelunom.',
'mailmypassword'          => 'Meli sebu dafi',
'passwordremindertitle'   => 'Nca sebu dafi temporali di {{SITENAME}}',
'passwordremindertext'    => 'Ku (sa a, dIP $1)
kusizi sebu dafi di {{SITENAME}} ($4).
Sebu dafi di sebelu "$2" sa "$3".
A sa menuhile e hloli zwa sebu dafi.

Sa ku bye fatukile zwa sebu dafi e a ni petuho, ni petuho e mulumiwasibukirisize.',
'noemail'                 => 'No meli di sebelu "$1".',
'passwordsent'            => 'Nca sebu dafi sa meli di sebelu "$1". Menuhile post tamibukisimelize.',
'eauthentsent'            => 'Meli sa meli di meli adresi. Pre xete meli sa meli di sebelu, inisidusize melisaku, di saguridimi sebelu.',
'mailerror'               => 'Bufosi afi mail: $1',
'accountcreated'          => 'Sebelu sa hloli',
'accountcreatedtext'      => 'Sebelu di $1 sa hloli.',
'createaccount-title'     => 'Sebelu sa hloli di {{SITENAME}}',
'loginlanguagelabel'      => 'Zwa Siselect: $1',

# Change password dialog
'resetpass'        => 'Lisetize sebelu sebu dafi',
'resetpass_header' => 'Lisetize sebu dafi',
'retypenew'        => 'Sebu dafi:',
'resetpass_submit' => 'Setize sebu dafi e menuhile',

# Edit page toolbar
'bold_sample'     => 'Selt ombelu',
'bold_tip'        => 'Selt ombelu',
'italic_sample'   => 'Selt itali',
'italic_tip'      => 'Selt itali',
'link_sample'     => "Sebu di ling'ko",
'link_tip'        => "Ling'ko bulili in",
'extlink_sample'  => "http://www.example.com sebu di ling'ko",
'extlink_tip'     => "Ling'ko bulili out (¡con http://!)",
'headline_sample' => 'Selt di pagafi',
'headline_tip'    => 'Pagafi (2)',
'nowiki_sample'   => "Sebu di 'ni-Wikicode' apukisize",
'nowiki_tip'      => "'Ni Wiki-code' apukisize",
'image_sample'    => 'Kamukile.jpg',
'image_tip'       => 'Kamukile imegi',
'media_sample'    => 'Kamukile.ogg',
'media_tip'       => 'Kamukile media',
'sig_tip'         => 'Sebu di sebelu con xete data (4× ~)',
'hr_tip'          => 'Lani - (sepalati)',

# Edit pages
'summary'                    => 'Lyangutukezi:',
'subject'                    => 'Lyangutukezi selt:',
'minoredit'                  => 'A sa pili kenki',
'watchthis'                  => 'Kantezi bye petulo',
'savearticle'                => 'Bulukezi',
'preview'                    => 'PendiBe',
'showpreview'                => 'Kamukile PendiBe',
'showlivepreview'            => "Lyangutukezi 'Live'",
'showdiff'                   => 'Kamukile nca petuho',
'anoneditwarning'            => "'''!:''' A ni sa menuhile.
Zwa adresi di IP sa bulukezi kwa kenki bundau di petulo.",
'summary-preview'            => 'Lyangutukezi pendiBe:',
'blockedtitle'               => 'Sebelu sa bolok',
'blockedtext'                => "'''Zwa sebelu/IP sa bolok.'''

$1 bolok a. Lyangutukezireason sa ''$2''.

* Bolok ungekile: $8
* Bolok simpekile: $6
* Tokwezi bolok: $7

A bulelezi $1/[[{{MediaWiki:Grouppage-sysop}}|xetewi sesop]] bolok.
A ni sebilize 'meli sebelu' ka a ni afi adresi di meli kwa zwa [[Special:Preferences|petohoni]] e no sa bolok di sebelize.
A IP sa $3, e ID di bolok sa #$5. Bulelezi IP e ID kwa bukizisize.",
'blockedoriginalsource'      => "Olige di '''$1''' sa kamukile:",
'blockededitsource'          => "Selt di '''zwa hloli ye ng'i''' di '''$1''' sa kamukile:",
'whitelistedittext'          => "A sa $1 di hloli ye ng'i petulo.",
'nosuchsectiontitle'         => 'Ni di lyangutukezi',
'loginreqlink'               => 'menuhile',
'loginreqpagetext'           => 'A sa $1 di kamukile xeti di petulo.',
'newarticle'                 => '(Nca)',
'newarticletext'             => "Bye petulo ni sa, tiguki zwa ling'ki.
Di hloli, seltisize kwa sisebelisoni (kamukile [[{{MediaWiki:Helppage}}|likitisize]]).
A sa nca di bufosi, tampi '''back'''.",
'noarticletext'              => 'Sa no selt kwa petulo, a sa [[Special:Search/{{PAGENAME}}|fatukile di petulonom]] kwa xete petulo/[{{fullurl:{{FULLPAGENAME}}|action=edit}} petulo kenki].',
'updated'                    => '(sa updeti)',
'note'                       => "'''Lyangutukezi:'''",
'previewnote'                => "'''A sa in kamukile PendiBe; petuho ni sa bulukezi!'''",
'editing'                    => "Hloli ye ng'i $1",
'editingsection'             => "Hloli ye ng'i $1 (lyangutukezi)",
'editingcomment'             => "Hloli ye ng'i $1 (lyangutukezi)",
'yourtext'                   => 'Zwa selt',
'storedversion'              => 'Selt bulukezi',
'yourdiff'                   => 'Petuhoni',
'copyrightwarning'           => "Xete kenki di {{SITENAME}} sa rilisi kwa $2 (fatukile $1 di pagu). A ni tokwezi zwa selt sa kenki a ridistributi kwa tokwi, ni bulukezi.<br />
A sumekezi zwa selt sa dya, a kopisize di publiki domeni, a ike risorsi.
'''NI BULUKEZI SELT KOPINITUMELELO E NI TUMELELO!'''",
'templatesused'              => 'Yegani sebelize di bye petulo:',
'templatesusedpreview'       => 'Yegani sebelize kwa bye PendiBe:',
'template-protected'         => '(sa bukelezi)',
'template-semiprotected'     => '(bukelezi di pagafi)',
'nocreatetext'               => '{{SITENAME}} sa simplekile petulo.
A afi e kenki/[[Special:UserLogin|menuhile]].',
'recreate-moveddeleted-warn' => "'''!: A sa hloli petulo dy sa afi kulobala.'''

A sa luku a kenki dyangitubilinisize petulo.
Desu dafi kulobala di petulo sa gi di informasi:",

# Account creation failure
'cantcreateaccounttitle' => 'Ni sa hloli di sebelu',

# History pages
'viewpagelogs'        => 'Kamukile desu di petulo',
'currentrev'          => 'Selt nca',
'revisionasof'        => 'Selt di $1',
'revision-info'       => 'Selt di $1 di $2',
'previousrevision'    => '←Kona selt',
'nextrevision'        => 'Lila selt→',
'currentrevisionlink' => 'Selt nca',
'cur'                 => 'bye',
'last'                => 'pu-lila',
'page_first'          => 'pu-kona',
'page_last'           => 'pu-lila',
'histlegend'          => 'Petuho seleksi: nyansulize selt sisebelisoni di radio e dusize enter.<br />
Informasi: (bye) = petuho a nca selt,
(pu-lila) = petuho a pre selt, p = pili kenki.',
'histfirst'           => 'Pu-kona',
'histlast'            => 'Pu-lila',
'historyempty'        => '(necafeti)',

# Revision feed
'history-feed-title'          => 'Bundau di selt',
'history-feed-description'    => 'Bundau di selt di petulo di wiki.',
'history-feed-item-nocomment' => '$1 di $2',

# Revision deletion
'rev-deleted-comment' => '(lyangutukezi sa afi kulobala)',
'rev-deleted-user'    => '(sebu di sebelu sa afi kulobala)',
'rev-deleted-event'   => '(petulo sa afi kulobala)',
'rev-delundel'        => 'kamukile/cwankekile',

# History merging
'mergehistory-from' => 'Petulo dolege:',

# Diffs
'history-title'           => 'Bundau di selt di "$1"',
'difference'              => '(Petuho kwa selt)',
'lineno'                  => 'Lani $1:',
'compareselectedversions' => 'Bapisize',
'editundo'                => "afi hloli ye ng'i",
'diff-multi'              => '({{PLURAL:$1|1 selt amebusilize|$1 selt amebusilize}} ni kamukile.)',

# Search results
'searchresults'         => 'Fatukile kamukile',
'searchsubtitle'        => "A fatukile di '''[[:$1]]'''",
'searchsubtitleinvalid' => "A fatukile di '''$1'''",
'titlematches'          => 'Sebu di petulo ekali',
'notitlematches'        => 'Ni sebu di petulo ekali',
'textmatches'           => 'Selt di petulo ekali',
'notextmatches'         => 'Ni selt di petulo ekali',
'prevn'                 => 'kona {{PLURAL:$1|$1}}',
'nextn'                 => 'lila {{PLURAL:$1|$1}}',
'viewprevnext'          => 'Kamukile ($1 {{int:pipe-separator}} $2) ($3)',
'searchhelp-url'        => 'Help:Buinaneli di petulo',
'searchall'             => 'xete',
'showingresults'        => "Kamukile opi {{PLURAL:$1|'''1''' ekali|'''$1''' ekalina}} di #'''$2'''.",
'showingresultsnum'     => "Kamukile {{PLURAL:$3|'''1''' ekali|'''$3''' ekalina}} di #'''$2'''.",
'powersearch'           => 'Fatukile',

# Quickbar
'qbsettings-none' => 'Ni',

# Preferences page
'preferences'               => 'Petohoni di sebelu',
'mypreferences'             => 'Zwa petohoni di sebelu',
'prefs-edits'               => "Hloli ye ng'inabi:",
'prefsnologin'              => 'Ni menuhile',
'prefs-skin'                => 'PendiBe',
'skin-preview'              => 'PendiBe',
'datedefault'               => 'Ni di petohoni di sebelu',
'prefs-datetime'            => 'Data',
'prefs-rc'                  => 'Petuho nca',
'prefs-watchlist'           => 'Mukoloko di kentezi',
'saveprefs'                 => 'Bulukezi',
'resetprefs'                => 'Lisetize',
'prefs-editing'             => "Hloli ye ng'i",
'rows'                      => 'Roo:',
'columns'                   => 'Kalom:',
'searchresultshead'         => 'Fatukile',
'resultsperpage'            => 'Hit di petulo:',
'timezoneoffset'            => 'Ufiseti¹',
'default'                   => 'auto',
'prefs-files'               => 'Imegini',
'youremail'                 => 'Imeli:',
'username'                  => 'Sebelu:',
'uid'                       => 'Sebelu ID:',
'yourrealname'              => 'Sebu monida:',
'yourlanguage'              => 'Siselect:',
'yourvariant'               => 'Pane:',
'yournick'                  => 'Kamukile di sebelu printezi:',
'badsig'                    => 'Ro sebu di sebelu con xete data bufosi; kamukile HTML tegina.',
'email'                     => 'Imeli',
'prefs-help-realname'       => 'Nom sa opsi e a sa kisize providisize sa tekini atribusi di zwa selt.',
'prefs-help-email-required' => 'Adressi di meli sa nidyisize.',

# Groups
'group-all' => '(xete)',

'grouppage-sysop' => '{{ns:project}}:Sesop',

# User rights log
'rightslog'  => 'Desu di petuhoni kwa sebelu',
'rightsnone' => '(ni)',

# Recent changes
'nchanges'                       => '$1 {{PLURAL:$1|petuho|petuho}}',
'recentchanges'                  => 'Petuho nca',
'recentchanges-feed-description' => 'Kamukile petuho nca di wiki kwa bye feed.',
'rcnote'                         => "Bye {{PLURAL:$1|sa '''1''' petuho|sa pu-lila '''$1''' petuhoni}} kwa pu-lila {{PLURAL:$2|dia|'''$2''' dia}}, di $3.",
'rcnotefrom'                     => "Bye sa petuho di '''$2''' (di '''$1''' sa kamukile).",
'rclistfrom'                     => 'Kamukile nca petuho di $1',
'rcshowhideminor'                => '$1 pili kenki',
'rcshowhidebots'                 => '$1 roboti',
'rcshowhideliu'                  => '$1 sebelu',
'rcshowhideanons'                => '$1 IP',
'rcshowhidepatr'                 => '$1 afina patoli',
'rcshowhidemine'                 => '$1 zwa afina',
'rclinks'                        => 'Kamukile lapu-lila $1 petuhoni di lapu-lila $2 dia<br />$3',
'diff'                           => 'petuho',
'hist'                           => 'bundau',
'hide'                           => 'Cwankekile',
'show'                           => 'Kamukile',
'minoreditletter'                => 'p',
'newpageletter'                  => 'n',
'boteditletter'                  => 'r',
'newsectionsummary'              => '/* $1 */ nca bulelezi',

# Recent changes linked
'recentchangeslinked'          => 'Petuho adusi',
'recentchangeslinked-feed'     => 'Petuho adusi',
'recentchangeslinked-toolbox'  => 'Petuho adusi',
'recentchangeslinked-title'    => 'Petuho dadusi di "$1"',
'recentchangeslinked-noresult' => "Ni petuhoni kwa ling'ki petulo kwa bye datum.",
'recentchangeslinked-summary'  => "Bye petulo zwenti kamukile lapu-kona petuho di petulo sa ling'ki. Petulo di zwa mukoloko di kentezi sa '''ombelu'''.",

# Upload
'upload'            => 'Imegi uplodezi',
'uploadbtn'         => 'Imegi uplodezi',
'uploadnologin'     => 'Ni menuhile',
'uploadnologintext' => 'A sa [[Special:UserLogin|menuhile]]
di uplodezi media.',
'uploaderror'       => 'Bufosi duplodezi',
'uploadlogpage'     => 'Desu di uplodezi',
'filename'          => 'Imegi',
'filedesc'          => 'Lyangutukezi',
'fileuploadsummary' => 'Lyangutukezi:',
'filesource'        => "Ng'i",
'uploadedfiles'     => 'Imegina uplodezi',
'savefile'          => 'Bulukezi imegi',
'uploadedimage'     => 'sa uplodezi "[[$1]]"',
'overwroteimage'    => 'sa uplodezi nca imegi petuho di "[[$1]]"',
'sourcefilename'    => "Ng'i di imegi",
'watchthisupload'   => 'Kentezi bye petulo',

'upload-file-error' => 'Interni bufosi',

'license-nopreview' => '(PendiBe di nupdeti)',

# Special:ListFiles
'imgfile'        => 'imegi',
'listfiles'      => 'Mukoloko di imegina',
'listfiles_user' => 'Sebelu',

# File description page
'file-anchor-link'          => 'Imegi',
'filehist'                  => 'Imegi bundau',
'filehist-help'             => 'Tampa datum/taimi di kamukile imegi a sa kwa bye datum.',
'filehist-current'          => 'bye',
'filehist-datetime'         => 'Datumi/Taimi',
'filehist-user'             => 'Sebelu',
'filehist-dimensions'       => 'Dimensyoni',
'filehist-filesize'         => 'Imegispani',
'filehist-comment'          => 'Lyangutukezi',
'imagelinks'                => "Ling'kina",
'linkstoimage'              => "Bye petulo sa ling'ki di bye media:",
'nolinkstoimage'            => "No petulo ling'ki a imegi.",
'sharedupload'              => 'Imegi sa uplodezi kwa wiki dy apukolobili sa e sa kubi xetewi proyeti.',
'uploadnewversion-linktext' => 'Uplodezi nca selt di bye media',

# File reversion
'filerevert-comment' => 'Lyangutukezi:',

# File deletion
'filedelete'         => 'Afi kulobala $1',
'filedelete-legend'  => 'Afi kulobala imegi',
'filedelete-intro'   => "Sa afi kulobala '''[[Media:$1|$1]]'''.",
'filedelete-comment' => 'Lyangutukezi:',
'filedelete-submit'  => 'Afi kulobala',
'filedelete-success' => "'''$1''' sa afi kulobala.",

# MIME search
'mimesearch' => 'MIME fatukile',
'download'   => 'dawnlodezi',

# List redirects
'listredirects' => 'Mukoloko di petulo abezi',

# Unused templates
'unusedtemplates' => 'Yegani kopu',

# Random page
'randompage' => 'Petulo fona',

# Random redirect
'randomredirect' => 'Petulo abezi fona',

# Statistics
'statistics'              => 'Mukoloko di kamukile',
'statistics-header-users' => 'Mukoloko di kamukile di sebelu',

'disambiguations' => 'Disamebigasina',

'doubleredirects' => 'Petulo abezi sa dužemi',

'brokenredirects'        => 'Petulo abezi bufosi',
'brokenredirects-edit'   => "hloli ye ng'i",
'brokenredirects-delete' => 'afi kulobala',

'withoutinterwiki' => 'Petulo dicon interwikina',

'fewestrevisions' => 'Petuho con lapu-mina hlolina',

# Miscellaneous special pages
'nbytes'                  => '$1 {{PLURAL:$1|bat|bati}}',
'ncategories'             => '$1 {{PLURAL:$1|kattegori|kattegorina}}',
'nlinks'                  => "$1 {{PLURAL:$1|ling'ki|ling'ki}}",
'nmembers'                => '$1 {{PLURAL:$1|peta|petani}}',
'nrevisions'              => '$1 {{PLURAL:$1|hloli|hlolina}}',
'nviews'                  => '$1 {{PLURAL:$1|kamukile|kamukile}}',
'specialpage-empty'       => 'Kamukile ni sa bundau.',
'lonelypages'             => "Petulo coni ling'ki di a",
'lonelypagestext'         => "Petulo kamukile ni sa con ling'ki di xeti petulo di {{SITENAME}}.",
'uncategorizedpages'      => 'Petulo coni kattegori',
'uncategorizedcategories' => 'Kattegori coni kattegori',
'uncategorizedimages'     => 'Imegi coni kattegori',
'uncategorizedtemplates'  => 'Yegani coni kattegori',
'unusedcategories'        => 'Kattegori kopu',
'unusedimages'            => 'Imegi kopu',
'popularpages'            => 'Petulo populali',
'wantedcategories'        => "Ni sa kattegorina con ling'ki",
'wantedpages'             => "Ni sa petulo con ling'ki",
'mostlinked'              => "Petulo con plus ling'ki di a",
'mostlinkedcategories'    => "Kattegorina con plus ling'ki di a",
'mostlinkedtemplates'     => "Yegani con plus ling'ki di a",
'mostcategories'          => 'Petulo con plus kattegorina',
'mostimages'              => "Imegi con plus ling'ki di a",
'mostrevisions'           => 'Petulo con plus hlolina',
'prefixindex'             => 'Petulo bye abuce pelifikise',
'shortpages'              => 'Mukoloko di kuswani petulo',
'longpages'               => 'Mukoloko di petulo–amuha',
'deadendpages'            => "Mukoloko di petulo-ni ling'ki",
'deadendpagestext'        => "Bye petulo ni sa ling'ki medi petulo di {{SITENAME}}.",
'protectedpages'          => 'Petulo sa bukelelize',
'listusers'               => 'Mukoloko di sebelu',
'newpages'                => 'Nca petulo',
'newpages-username'       => 'Sebelu:',
'ancientpages'            => 'Petulo bye sa kona afina',
'move'                    => 'Nyanganyisize',
'movethispage'            => 'Nyanganyisize bye petulo',

# Book sources
'booksources'    => 'Desusorsi',
'booksources-go' => 'Afi',

# Special:Log
'specialloguserlabel'  => 'Sebelu:',
'speciallogtitlelabel' => 'Sebu:',
'log'                  => 'Desuni',
'all-logs-page'        => 'Xete desu',

# Special:AllPages
'allpages'       => 'Mukoloko di petulo',
'alphaindexline' => '$1 di $2',
'nextpage'       => 'Lila petulo ($1)',
'prevpage'       => 'Kona petulo ($1)',
'allpagesfrom'   => 'Kamukile petulo di:',
'allarticles'    => 'Mukoloko di petulo',
'allpagesprev'   => 'Kona',
'allpagesnext'   => 'Lila',
'allpagessubmit' => 'Afi',
'allpagesprefix' => 'Kamukile petulo di pifeto di:',

# Special:Categories
'categories' => 'Kattegori',

# Special:DeletedContributions
'deletedcontributions'       => 'Afina di sebelu bye sa afi kulobala',
'deletedcontributions-title' => 'Afina di sebelu bye sa afi kulobala',

# Special:ListUsers
'listusersfrom'      => 'Kamukile sebelu di:',
'listusers-submit'   => 'Kamukile',
'listusers-noresult' => 'Ni-di sebelu.',

# E-mail user
'emailuser'       => 'Imeli bye sebelu',
'emailpage'       => 'Imeli sebelu',
'defemailsubject' => '{{SITENAME}} meli',
'noemailtitle'    => 'Ni meli adresi',
'noemailtext'     => 'Bye sebelu ni sa meli adresi,
dicon sa sosize ni sa meli di kupo sebelu.',
'emailfrom'       => 'Poti',
'emailto'         => 'Atipo',
'emailsubject'    => 'Lyangutukezi',
'emailmessage'    => 'Mulumiwa',
'emailsend'       => 'Afi',
'emailsent'       => 'Meli sa afi',
'emailsenttext'   => 'Zwa meli sa afi.',

# Watchlist
'watchlist'         => 'Zwa mukoloko di kentezi',
'mywatchlist'       => 'Zwa mukoloko di kentezi',
'watchnologin'      => 'A ni sa menuhile',
'watchnologintext'  => "A sa [[Special:UserLogin|menuhile]] di hloli ye ng'i zwa mukoloko di kentezi.",
'addedwatchtext'    => "Petulo \"[[:\$1]]\" sa vugisize di zwa [[Special:Watchlist|mukoloko di kentezi]].
Petuhoni di bye petulo e sa bulelezi sa mukolokosize ta, e '''ombelu''' kwa [[Special:RecentChanges|petuho nca]] di kwazidisize akusize.

A sa afi kulobala di zwa mukoloko di kentezi, tampi \"ngambu kentezi\".",
'removedwatchtext'  => 'Petulo "[[:$1]]" sa afi kulobala di zwa mukoloko di kentezi.',
'watch'             => 'Kentezi',
'watchthispage'     => 'Kentezi bye petulo',
'unwatch'           => 'Ngambu kentezi',
'unwatchthispage'   => 'Ngambu kentezi',
'notanarticle'      => 'Ni di petulo infomelo',
'watchlist-details' => '{{PLURAL:$1|$1 petulo|$1 petulo}} sa kentezi e no bulelezi.',
'wlshowlast'        => 'Kamukile lapu-lila $1 holani $2 dia $3',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'Kentezi...',
'unwatching' => 'Dikentezi...',

'enotif_newpagetext'           => 'Bye sa nca petulo.',
'enotif_impersonal_salutation' => '{{SITENAME}} sebelu',
'changed'                      => 'petuhoni',
'created'                      => 'hlolini',

# Delete
'deletepage'            => 'Afi kulobala petulo',
'confirm'               => 'Afi pe',
'excontent'             => "Petulo sa ng'i: '$1'",
'excontentauthor'       => "Petulo sa ng'i: '$1' (sebelu sa ng'i '[[Special:Contributions/$2|$2]]')",
'exbeforeblank'         => "Petulo sa ng'i blanco: '$1'",
'exblank'               => 'petulo sa blanco',
'historywarning'        => 'Petulo, sa afi kulobala, sa bundau di sebelu:',
'confirmdeletetext'     => 'A sa afi kulobala petulo e bundau. A sa ukisize a sa ni bufosi e a sa iki di  [[{{MediaWiki:Policy-url}}|polisi]].',
'actioncomplete'        => 'Sa afi',
'deletedtext'           => '"$1" sa afi kulobala. Fatukile $2 di desu di afi kulobala nca.',
'deletedarticle'        => 'sa afi kulobala "[[$1]]"',
'dellogpage'            => 'Desu di afi kulobala',
'deletecomment'         => 'Lyangutukezi:',
'deleteotherreason'     => 'Xetewi/ewi lyangutukezi:',
'deletereasonotherlist' => 'Xetewi lyangutukezi',

# Rollback
'rollback'       => "Afi hlolina ye ng'i lila",
'rollback_short' => "Afi hloli ye ng'i lila",
'rollbacklink'   => "afi hloli ye ng'i lila",
'rollbackfailed' => "Bufosi dafi hloli ye ng'i lila",

# Protect
'protectlogpage'              => 'Desu di bukelize',
'protectedarticle'            => 'sa bukelelize "[[$1]]"',
'unprotectedarticle'          => 'sa ati-bukelelize "[[$1]]"',
'prot_1movedto2'              => '[[$1]] nyanganyisize di [[$2]]',
'protect-legend'              => 'Bukelezi',
'protectcomment'              => 'Lyangutukezi:',
'protectexpiry'               => 'Simpekile:',
'protect_expiry_invalid'      => 'Bufosi di simpekile.',
'protect_expiry_old'          => 'Simpekile sa kwa bundau.',
'protect-text'                => "A sa kamukile e hloli bukelezi di petulo '''$1'''.",
'protect-locked-access'       => "Zwa sebelu ni sa hloli bukelezi.
Petohoni di petulo '''$1''' sa:",
'protect-cascadeon'           => 'Bye petulo sa bukelezi a sa kwa bye {{PLURAL:$1|petulo|petulo}}, asa kaskedi. A sa hloli bukelezi, a ni sa afakize kaskedi.',
'protect-default'             => '(auto)',
'protect-fallback'            => 'No "$1" tumelelo',
'protect-level-autoconfirmed' => 'Bolok sebelu dIP',
'protect-level-sysop'         => 'Sesopinuli',
'protect-summary-cascade'     => "xete ling'ki kentezi",
'protect-expiring'            => 'simpekile $1 (UTC)',
'protect-cascade'             => 'Bukelezi petulo kwa bye petulo (kaskedi)',
'protect-cantedit'            => "A ni ku hloli a bukelezi di bye petulo, a ni sa tumelelo di hloli ye ng'i.",
'protect-expiry-options'      => '2 ora:2 hours,1 dia:1 day,3 dia:3 days,1 wiki:1 week,2 wiki:2 weeks,1 muna:1 month,3 muna:3 months,6 muna:6 months,1 anu:1 year,di simuluzi:infinite',
'restriction-type'            => 'Tumelelo:',
'restriction-level'           => 'Bolok tumelelo:',

# Restrictions (nouns)
'restriction-edit'   => "Hloli ye ng'i",
'restriction-move'   => 'Nyanganyisize',
'restriction-create' => 'Hloli',

# Restriction levels
'restriction-level-all' => 'xete',

# Undelete
'undelete'               => 'Kamukile afi kulobala petulo',
'viewdeletedpage'        => 'Kamukile afi kulobala petulo',
'undeletebtn'            => 'Ati-afi kulobala',
'undeletereset'          => 'Lisetize',
'undeletecomment'        => 'Lyangutukezi:',
'undeletedarticle'       => 'sa ati-afi kulobala "[[$1]]"',
'undelete-search-box'    => 'Fatukile afi kulobala petulo',
'undelete-search-prefix' => 'Kamukile petulo di:',
'undelete-search-submit' => 'Fatukile',

# Namespace form on various pages
'namespace'      => 'Fatukile efro:',
'invert'         => "Fatukile efro ye ng'i",
'blanknamespace' => '(Yem efro)',

# Contributions
'contributions' => 'Afina di sebelu',
'mycontris'     => 'Zwa afina',
'contribsub2'   => 'Di $1 ($2)',
'uctop'         => "(nca ng'i)",
'month'         => 'Di muna (previ):',
'year'          => 'Dyanu (previ):',

'sp-contributions-newbies'     => 'Kamukile afina di sebelu nca',
'sp-contributions-newbies-sub' => 'Di nca sebelu',
'sp-contributions-blocklog'    => 'Desu di bolok',
'sp-contributions-deleted'     => 'Afina di sebelu bye sa afi kulobala',
'sp-contributions-talk'        => 'Bulelezi',
'sp-contributions-search'      => 'Fatukile di afina',
'sp-contributions-username'    => 'IP/sebelu:',
'sp-contributions-submit'      => 'Fatukile',

# What links here
'whatlinkshere'       => "Ling'ki di bye petulo",
'whatlinkshere-title' => "Petulo bye ling'ki di $1",
'whatlinkshere-page'  => 'Petulo:',
'linkshere'           => "Bye petulo ling'ki di '''[[:$1]]''':",
'nolinkshere'         => "0 petulo ling'ki di '''[[:$1]]'''.",
'nolinkshere-ns'      => "0 petulo ling'ki di '''[[:$1]]''' bye sa di bye fatukile efro.",
'isredirect'          => 'petulo abezi',
'istemplate'          => "yang'idole",
'whatlinkshere-prev'  => '{{PLURAL:$1|kona|kona $1}}',
'whatlinkshere-next'  => '{{PLURAL:$1|lila|lila $1}}',
'whatlinkshere-links' => "← ling'ki",

# Block/unblock
'blockip'            => 'Bolok sebelu',
'ipadressorusername' => 'IP/sebelu:',
'ipboptions'         => '2 ora:2 hours,1 dia:1 day,3 dia:3 days,1 wiki:1 week,2 wiki:2 weeks,1 muna:1 month,3 muna:3 months,6 muna:6 months,1 anu:1 year,di simuluzi:infinite',
'badipaddress'       => 'IP ni sa',
'ipblocklist'        => 'Mukoloko di IP e sebelu bye sa bolok',
'ipblocklist-submit' => 'Fatukile',
'blocklink'          => 'bolok',
'unblocklink'        => 'bolok tamuhile',
'contribslink'       => 'afina',
'blocklogpage'       => 'Desu di bolok',
'blocklogentry'      => 'sa bolok [[$1]] e simpekile sa $2 $3',
'proxyblocksuccess'  => 'Afi.',

# Move page
'move-page-legend' => 'Nyanganyisize petulo',
'movepagetext'     => "A sa nyanganyisize xete bundau di nom nca e petulo.
Xisiti nom sa petulo abezi post nyanganyisize.
Ling'ki di xisiti nom no kenki; luku di petulo abezi bufosi e petulo abezi sa bužemi.
A sa gutukilimisize di ling'ki.

Petulo sa '''no''' nyanganyisize di nca nom e nca nom sa xete, xete a sa petulo abezi e ni bundau/no selt petulo. A sa nyanganyisize petulo a orži.

'''!'''
Petulo populari sa drastiki bufosi e nyanganyisize;
a sa gukilize di nyanganyisize.",
'movepagetalktext' => "Bulelezi sa nyanganyisize '''teri:'''
*Bulelezi e selt sa kwa nca nom,
*Okižekilize sisebelisoni.

Teri yaki, a nyanganyisize.",
'movearticle'      => 'Nyanganyisize petulo:',
'movenologin'      => 'A ni sa menuhile',
'newtitle'         => 'Di nca petulo:',
'move-watch'       => 'Kentezi bye petulo',
'movepagebtn'      => 'Nyanganyisize petulo',
'pagemovedsub'     => 'Nyanganyisize sa afi.',
'articleexists'    => 'Petulo zwa nyanganyisize afi sa, e nom sa bufosi. Xete nom sa kulikawi.',
'talkexists'       => "'''No bufosi di nyanganyisize petulo, bufosi di nyanganyisize bulelezi, tubi hani.'''",
'movedto'          => 'nyanganyisize di',
'movetalk'         => 'Nyanganyisize petulo di bulelezi',
'1movedto2'        => '[[$1]] nyanganyisize di [[$2]]',
'1movedto2_redir'  => '[[$1]] nyanganyisize di [[$2]] alo petulo abezi',
'movelogpage'      => 'Desu di nyanganyisize',
'movelogpagetext'  => 'Bye mukoloko sa mukoloko di petulo nyanganyisize.',
'movereason'       => 'Lyangutukezi:',
'revertmove'       => 'afi',
'delete_and_move'  => 'Afi kulobala alo-di nyanganyisize',

# Export
'export'        => 'Petulo export',
'export-submit' => 'Petulo export',

# Namespace 8 related
'allmessages'        => 'Mulumiwani',
'allmessagesname'    => 'Sebu',
'allmessagesdefault' => 'Selt orge',
'allmessagescurrent' => 'Selt nca',
'allmessagestext'    => 'Bye mukoloko sa mukoloko di mulumiwani di MediaWiki poo.
Please visit [//www.mediawiki.org/wiki/Localisation MediaWiki Localisation] and [//translatewiki.net translatewiki.net] if you wish to contribute to the generic MediaWiki localisation.',

# Thumbnails
'thumbnail-more'  => 'Pusize',
'thumbnail_error' => 'Bufosi hloli tumbneli: $1',

# Special:Import
'import'                  => 'Petulo import',
'import-interwiki-submit' => 'Petulo import',
'import-comment'          => 'Lyangutukezi:',

# Import log
'importlogpage' => 'Desu di import',

# Tooltip help for the actions
'tooltip-pt-userpage'             => 'Zwa sebelu petulo',
'tooltip-pt-anonuserpage'         => "Petulo di sebelu di IP, sa hloli ye ng'i.",
'tooltip-pt-mytalk'               => 'Zwa bulelezi petulo',
'tooltip-pt-anontalk'             => 'Bulelezi di hlolina di bye IP',
'tooltip-pt-preferences'          => 'Zwa petohoni di sebelu',
'tooltip-pt-watchlist'            => 'Mukoloko di petulo a kentezi di petuhoni',
'tooltip-pt-mycontris'            => 'Mukoloko di zwa afina',
'tooltip-pt-login'                => 'A sa ikokotozi di menuhile, a ni sa musebezi.',
'tooltip-pt-logout'               => 'Ile',
'tooltip-ca-talk'                 => 'Bulelezi di bye petulo',
'tooltip-ca-edit'                 => "A sa hloli ye ng'i bye petulo. Kamukile PendiBe pe bulukezi.",
'tooltip-ca-addsection'           => 'Lyangutukezi bye bulelezi.',
'tooltip-ca-viewsource'           => 'Bye petulo sa bukelezi. A sa kamukile afina.',
'tooltip-ca-history'              => 'Petuho kona, bundau, di petulo.',
'tooltip-ca-protect'              => 'Bukelezi bye petulo',
'tooltip-ca-delete'               => 'Afi kulobala bye petulo',
'tooltip-ca-move'                 => 'Nyanganyisize bye petulo',
'tooltip-ca-watch'                => 'Tendile petulo kwa zwa mukoloko di kentezi',
'tooltip-ca-unwatch'              => 'Afi kulobala bye petulo di zwa mukoloko di kentezi',
'tooltip-search'                  => 'Fatukile {{SITENAME}}',
'tooltip-search-fulltext'         => 'Fatukile petulo di bye selt',
'tooltip-p-logo'                  => 'Petulo yem efro',
'tooltip-n-mainpage'              => 'Sadi petulo yem efro',
'tooltip-n-portal'                => 'Con e di poyeti, o a sa, o a sa fatukile',
'tooltip-n-currentevents'         => 'Fatukile informasi di muembatami',
'tooltip-n-recentchanges'         => 'Mukoloko di petuho nca di wiki.',
'tooltip-n-randompage'            => 'Apuzi petulo fona',
'tooltip-n-help'                  => 'Yembani di fatukile.',
'tooltip-t-whatlinkshere'         => "Mukoloko di xete petulo di wiki bye sa ling'ki",
'tooltip-t-recentchangeslinked'   => "Petuho nca di petulo sa ling'ki di bye petulo",
'tooltip-feed-rss'                => 'RSS feed bye petulo',
'tooltip-feed-atom'               => 'Atom feed bye petulo',
'tooltip-t-contributions'         => 'Kamukile mukoloko di afina di bye sebelu',
'tooltip-t-emailuser'             => 'Afi meli di bye sebelu',
'tooltip-t-upload'                => 'Imegi/media uplodezi',
'tooltip-t-specialpages'          => 'Mukoloko di xete petulo zwenti',
'tooltip-t-print'                 => 'Petulo printezi di bye petulo',
'tooltip-t-permalink'             => 'Permalink di bye selt di petulo',
'tooltip-ca-nstab-main'           => 'Kamukile xadine petulo',
'tooltip-ca-nstab-user'           => 'Kamukile sebelu petulo',
'tooltip-ca-nstab-media'          => 'Kamukile imegi petulo',
'tooltip-ca-nstab-special'        => "Bye sa petulo zwenti, a ni sa hloli ye ng'i bye petulo",
'tooltip-ca-nstab-project'        => 'Kamukile prohyeti petulo',
'tooltip-ca-nstab-image'          => 'Kamukile imegi petulo',
'tooltip-ca-nstab-mediawiki'      => 'Kamukile mulumiwa petulo',
'tooltip-ca-nstab-template'       => 'Kamukile yegani petulo',
'tooltip-ca-nstab-help'           => 'Kamukile likitisize petulo',
'tooltip-ca-nstab-category'       => 'Kamukile kattegori petulo',
'tooltip-minoredit'               => 'Afi kenki ka pili kenki',
'tooltip-save'                    => 'Bulukezi zwa petuhoni',
'tooltip-preview'                 => 'Kamukile zwa petuhoni, sa bye pe bulukezi!',
'tooltip-diff'                    => 'Kamukile zwa petuhoni di selt.',
'tooltip-compareselectedversions' => 'Kamukile petuhoni di 2 bapisize di bye petulo.',
'tooltip-watch'                   => 'Tendile petulo kwa zwa mukoloko di kentezi',
'tooltip-recreate'                => 'Hloli bye petulo sonis a sa afi kulobala',
'tooltip-upload'                  => 'Uplodezi',

# Attribution
'anonymous' => 'Sebelu con IP di {{SITENAME}}',
'siteuser'  => '{{SITENAME}} sebelu $1',
'siteusers' => '{{SITENAME}} sebelu $1',

# Patrol log
'patrol-log-auto' => '(auto)',

# Image deletion
'filedeleteerror-short' => 'Bufosi di afi kulobala di media/imegi: $1',
'filedeleteerror-long'  => 'Bufosi sa, abi sa afi kulobala di media/imegi:

$1',

# Browsing diffs
'previousdiff' => '← Kona petuho',
'nextdiff'     => 'Lila petuho →',

# Media information
'widthheightpage' => '$1×$2, $3 petulo',
'file-info-size'  => '$1 × $2 pixel, imegi: $3, MIME type: $4',
'file-nohires'    => '<small>A sa risolusi aku balise.</small>',
'svg-long-desc'   => 'SVG imegi, nominali $1 × $2 pixel, imega: $3',
'show-big-image'  => 'Risolusi bakisize',

# Special:NewFiles
'newimages'             => 'Imegina nca',
'ilsubmit'              => 'Fatukile',
'sp-newimages-showfrom' => 'Kamukile nca imegi di $1',

# Bad image list
'bad_image_list' => "A fumato sa:

Xi mukoloko petulo (di *) sa konsidisize. 1-ling'ki di lina sa ling'ki dimegi bufosi.
Xete ling'ki kwa lina sa konsidisize desepo. Petulo dimedi inlinenikusize.",

# Metadata
'metadata'          => 'Metadatani',
'metadata-help'     => 'Imega sa informasi,di kamera digitali/skenni. Sat, imega sa kenki di selt nyazi, informasi kubalisize di kenki imegi.',
'metadata-expand'   => 'Kamukile datani',
'metadata-collapse' => 'Cwankekile petulo tabu',
'metadata-fields'   => 'EXIF metadata fields mukoloko kwa mulumiwa sa ike kwa imegipetulo ka metadata tablu sa tibekile. Xetewi sa cwankekile auto.
* make
* model
* datetimeoriginal
* exposuretime
* fnumber
* isospeedratings
* focallength
* artist
* copyright
* imagedescription
* gpslatitude
* gpslongitude
* gpsaltitude',

# EXIF tags
'exif-imagedescription' => 'Sebu di imegi',

# External editor support
'edit-externally'      => 'Kenki imegi sebilize pagini lakusi',
'edit-externally-help' => 'Boniselelize [//www.mediawiki.org/wiki/Manual:External_editors instruksi setup] kwa informasi.',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'xeti',
'namespacesall' => 'xeti',
'monthsall'     => 'xeti',

# Trackbacks
'trackbackremove' => '([$1 afi kulobala])',

# action=purge
'confirm_purge_button' => 'Afi',

# Multipage image navigation
'imgmultipageprev' => '← kona petulo',
'imgmultipagenext' => 'lila petulo →',
'imgmultigo'       => 'Afi!',

# Table pager
'ascending_abbrev'         => 'asendin',
'descending_abbrev'        => 'disendin',
'table_pager_next'         => 'Lila petulo',
'table_pager_prev'         => 'Kona petulo',
'table_pager_limit'        => 'Kamukile $1 hits di petulo',
'table_pager_limit_submit' => 'Afi',
'table_pager_empty'        => 'Ni-di lani con info',

# Auto-summaries
'autosumm-blank'   => 'Sa blanki petulo',
'autosumm-replace' => "Sa blanki info con '$1'",
'autoredircomment' => 'Abezi di [[$1]]',
'autosumm-new'     => 'Nca petulo: $1',

# Watchlist editor
'watchlistedit-numitems'      => 'Zwa mukoloko di kentezi sa pozefisize {{PLURAL:$1|1 petulo|$1 petulo}}, dicon bulelezina.',
'watchlistedit-noitems'       => 'Zwa mukoloko di kentezi sa pozefisize 0 petulo.',
'watchlistedit-normal-title'  => "Hloli ye ng'i mukoloko di kentezi",
'watchlistedit-normal-legend' => 'Afi kulobala petulo di mukoloko di kentezi',
'watchlistedit-normal-submit' => 'Afi kulobala petulo',
'watchlistedit-normal-done'   => '{{PLURAL:$1|1 petulo|$1 petulo}} sa afi kulobala di zwa mukoloko di kentezi:',
'watchlistedit-raw-title'     => "Hloli ye ng'i ro mukoloko di kentezi",
'watchlistedit-raw-legend'    => "Hloli ye ng'i ro mukoloko di kentezi",
'watchlistedit-raw-titles'    => 'Petulo:',
'watchlistedit-raw-submit'    => 'Updetisize mukoloko di kentezi',
'watchlistedit-raw-done'      => 'Zwa mukoloko di kentezi sa updetisize.',
'watchlistedit-raw-removed'   => '{{PLURAL:$1|1 petulo|$1 petulo}} sa afi kulobala:',

# Watchlist editing tools
'watchlisttools-view' => 'Kamukile petuho desi imepotani',
'watchlisttools-edit' => "Kamukile e hloli ye ng'i mukoloko di kentezi",
'watchlisttools-raw'  => "Hloli ye ng'i ro mukoloko di kentezi",

# Special:Version
'version' => 'Pane',

# Special:SpecialPages
'specialpages' => 'Petulo zwenti',

);
